<?php
require_once('../path.php');
require_once('base/main_handlers.php');
require_once('lib/util.php');

/**
 * Top level code for commnad-line utilities.
 *
 * @param string $taskName - name of task being performed (to be appeared in messages and in log)
 * @param string $worker - Name of function that does real work and accepts
 *      configuration object as parameter.
 */
function cmd_main($taskName, $worker, $exitFunc = 'die', $echoFunc = 'printf') {
    if ($_SERVER['argc'] > 0) { // If running from command line
        $config_file = $_SERVER['argv'][1];
        try {
            $configuration = lib_Config::get($config_file);
            configure_error_handling();
            lib_Config::getLog()->info("[begin] $taskName.");
            $worker($configuration);
            lib_Config::getLog()->info("[end] $taskName." );
        } catch (Exception $e) {
            $logFileName = lib_Config::get()->log_file;
            lib_Config::getLog()->error(
                "[end] $taskName: exception caught at top level {$e->getMessage()}" );
            $echoFunc("$taskName failed: {$e->getMessage()}."
                . " See log file {$logFileName} for detailed output.\n");
            $exitFunc(1);
        }
    } else {
        $echoFunc("This code should be started from command line.\n");
        $exitFunc(1);
    }
}

?>